Finally add a teaspoon of salt and tumeric.

{comment Could mention useful tools for combining mixture}

Combine and mix ingredients in a large bowl.

{comment Should also add temperature in Fahrenheit}

Bake at 180C for 40 minutes.
